import express from 'express';
import { auth } from '../../middleware/auth';
import { searchArticles } from './controllers/search';
import { listArticles } from './controllers/list';
import { getArticle, createArticle, updateArticle, deleteArticle, importArticles, activeArticle } from './controllers/crud';

const router = express.Router();

// Поиск и список routes
router.get('/search', searchArticles);
router.get('/', listArticles);

// Импорт route
// Настройка middleware для обработки JSON
router.use(express.json({ limit: '10mb' }));
router.post('/import', auth, importArticles);

// CRUD routes
router.get('/:id', getArticle);
router.post('/', auth, createArticle);
router.put('/:id', auth, updateArticle);
router.put('/active/:id', auth, activeArticle);
router.delete('/:id', auth, deleteArticle);

export default router;